@@ -19,10 +19,10 @@
 #include "keduvocdocument.h"
 
 #include <QCoreApplication>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTextStream>
-#include <QtCore/QtAlgorithms>
-#include <QtCore/QIODevice>
+#include <QFileInfo>
+#include <QTextStream>
+#include <QtAlgorithms>
+#include <QIODevice>
 #include <QTemporaryFile>
 
 #include <QDebug>
@@ -74,7 +74,7 @@ public:
 
     /** autosave file used to provide locking access to the underlying file
      * Note: It is a pointer to allow locking a new file, saving results and
-     * then transfering the lock to m_autosave without risking loss of lock.
+     * then transferring the lock to m_autosave without risking loss of lock.
      * See saveAs for clarification*/
     KAutoSaveFile            *m_autosave;
 
